@@ -2,13 +2,16 @@
 
 import re
 
+from il2ds_log_parser.constants import (TOGGLE_VALUE_ON, TOGGLE_VALUE_OFF,
+    TARGET_RESULT_COMPLETE, TARGET_RESULT_FAILED, )
+
 __all__ =  [
     'RX_FLAGS',
     'RX_MISSION_BEGIN', 'RX_MISSION_END', 'RX_MISSION_PLAYING',
-    'RX_MISSION_WON', 'RX_TARGET_END',
+    'RX_MISSION_WON', 'RX_TARGET_RESULT',
     'RX_CONNECTED', 'RX_DISCONNECTED', 'RX_WENT_TO_MENU', 'RX_SELECTED_ARMY',
     'RX_SEAT_OCCUPIED', 'RX_WEAPONS_LOADED', 'RX_BAILED_OUT',
-    'RX_PARACHUTE_OPENED', 'RX_CAPTURED', 'RX_TOOK_OFF', 'RX_CRASHED',
+    'RX_SUCCESSFULLY_BAILED_OUT', 'RX_CAPTURED', 'RX_TOOK_OFF', 'RX_CRASHED',
     'RX_LANDED', 'RX_TOGGLE_LANDING_LIGHTS', 'RX_TOGGLE_WINGTIP_SMOKES',
     'RX_WOUNDED', 'RX_HEAVILY_WOUNDED', 'RX_KILLED', 'RX_KILLED_BY_USER',
     'RX_SHOT_DOWN_BY_USER', 'RX_SHOT_DOWN_BY_STATIC', 'RX_SHOT_DOWN_SELF',
@@ -114,10 +117,10 @@ RX_TOGGLE_VALUE = """
 # "on" will be captured into 'value' group.
                 # any beginning of the string
 (?P<value>      # 'value' group start
-    on|off      # switch value (e.g. 'on' or 'off')
+    {on}|{off}  # switch value (e.g. 'on' or 'off')
 )               # 'value' group end
                 # any ending of the string
-"""
+""".format(on=TOGGLE_VALUE_ON, off=TOGGLE_VALUE_OFF)
 
 RX_CALLSIGN = """
 # Capturing pilot's callsign. E.g.:
@@ -360,7 +363,7 @@ WON             #
 $               # end of the string
 """.format(datetime=RX_DATE_TIME, army=RX_ARMY)
 
-RX_TARGET_END = """
+RX_TARGET_RESULT = """
 # Capture 'target end' event. E.g.:
 #
 # "[8:33:05 PM] Target 3 Complete"
@@ -376,12 +379,13 @@ Target          #
 )               # 'number' group end
 \s              # single whitespace
 (?P<result>     # 'result' group start
-    Complete    #
+    {complete}  #
     |           # or
-    Failed      #
+    {failed}    #
 )               # 'result' group end
 $               # end of the string
-""".format(time=RX_TIME)
+""".format(time=RX_TIME,
+           complete=TARGET_RESULT_COMPLETE, failed=TARGET_RESULT_FAILED)
 
 #------------------------------------------------------------------------------
 # Action events
@@ -543,7 +547,7 @@ out             #
 {pos}           # 'position' regex placeholder
 """.format(time_seat=RX_TIME_SEAT, pos=RX_POS)
 
-RX_PARACHUTE_OPENED = """
+RX_SUCCESSFULLY_BAILED_OUT = """
 # Capture 'crew member's parachute opened' event. E.g.:
 #
 # "[9:33:20 PM] User:Pe-8(0) successfully bailed out at 100.0 200.99"
